@@ -8,7 +8,11 @@ from httpx import AsyncClient
 from meilisearch_python_async._http_requests import _HttpRequests
 from meilisearch_python_async.errors import MeiliSearchApiError
 from meilisearch_python_async.index import Index
-from meilisearch_python_async.models import ClientStats, DumpInfo, Health, IndexInfo, Keys, Version
+from meilisearch_python_async.models.client import ClientStats, Keys
+from meilisearch_python_async.models.dump import DumpInfo
+from meilisearch_python_async.models.health import Health
+from meilisearch_python_async.models.index import IndexInfo
+from meilisearch_python_async.models.version import Version
 
 
 class Client:
@@ -121,7 +125,7 @@ class Client:
             await self._http_requests.delete(url)
             return True
         except MeiliSearchApiError as error:
-            if error.error_code != "index_not_found":
+            if error.code != "index_not_found":
                 raise error
             return False
 
@@ -283,7 +287,7 @@ class Client:
         try:
             index_instance = await self.get_index(uid)
         except MeiliSearchApiError as err:
-            if "index_not_found" not in err.error_code:
+            if "index_not_found" not in err.code:
                 raise err
             index_instance = await self.create_index(uid, primary_key)
         return index_instance
