@@ -21,13 +21,10 @@ from meilisearch_python_async.errors import (
     MeiliSearchTimeoutError,
     PayloadTooLarge,
 )
-from meilisearch_python_async.models import (
-    IndexStats,
-    MeiliSearchSettings,
-    SearchResults,
-    UpdateId,
-    UpdateStatus,
-)
+from meilisearch_python_async.models.index import IndexStats
+from meilisearch_python_async.models.search import SearchResults
+from meilisearch_python_async.models.settings import MeiliSearchSettings
+from meilisearch_python_async.models.update import UpdateId, UpdateStatus
 
 
 class Index:
@@ -120,7 +117,7 @@ class Index:
             await self.delete()
             return True
         except MeiliSearchApiError as error:
-            if error.error_code != "index_not_found":
+            if error.code != "index_not_found":
                 raise error
             return False
 
